require "#{File.dirname(__FILE__)}/../lib/spec_helper.rb"

describe 'The Dashboard' do

  before :all do
    visit_dashboard

    # wait for nodes to load
    session.should have_css("#content", :visible => true)
  end

  after :all do
    logout
  end

  describe 'group management' do

    s_class_name_01 = 'sample::class01'
    s_class_name_02 = 'sample::class02'
    s_group_name_01 = 'sample::group01'
    s_group_name_02 = 'sample::group02'
    s_node_name_01  = 'sample::node01'
    s_node_name_02  = 'sample::node02'

    before :all do
      create_class(s_class_name_01) 
      create_class(s_class_name_02) 
      create_group(s_group_name_01)
      create_group(s_group_name_02)
      create_node(s_node_name_01)
      create_node(s_node_name_02)
    end

    after :all do
      remove_class(s_class_name_01) 
      remove_class(s_class_name_02) 
      remove_group(s_group_name_01)
      remove_group(s_group_name_02)
      remove_node(s_node_name_01)
      remove_node(s_node_name_02)
    end

    it 'should add and remove a simple group' do
      group_name = 'test::group'
      create_group(group_name)
      should_have_group(group_name)
      remove_group(group_name)
      should_not_have_group(group_name)
    end

    describe 'advanced insert' do

      group_name        = 'test::group'
      group_description = 'Description of test::group'
      params            = [{ :key => 'k1', :value => 'v1'}, { :key => 'k2', :value => 'v2'}]
 
      before :all do
        create_advanced_group(group_name, group_description, params, s_class_name_01, s_group_name_01, s_node_name_01)
      end

      after :all do
        remove_group(group_name)
      end

      it 'should add a group' do
        should_have_group(group_name)
      end

      it 'should have the set description' do
        select_group(group_name)
        session.should have_css('div#main div[class*="description"] p', :text => group_description)
      end

      it 'should have the added variables' do
        select_group(group_name)
        show_should_have_variables(params)
      end

      it 'should have the set class' do
        select_group(group_name)
        classes_table = get_inspector_table('Classes')
        classes_table.should have_css('a', :text => s_class_name_01)
      end

      it 'should have the set group' do
        select_group(group_name)
        classes_table = get_inspector_table('Groups')
        classes_table.should have_css('a', :text => s_group_name_01)
      end

      it 'should have the set node' do
        select_group(group_name)
        session.should have_css(%Q{div#main table.main a[href*="#{s_node_name_01}"]}, :text => s_node_name_01)
      end
    end

    describe 'advanced modification' do

      group_name        = 'test::group'
      group_description = 'Description of test::group'
      params            = [{ :key => 'k1', :value => 'v1'}, { :key => 'k2', :value => 'v2'}]
 
      group_name_new        = 'test::groupnew'
      group_description_new = 'Description of test::groupnew'
      params_new            = [{ :key => 'k1', :value => 'v0'}]
 
      before :all do
        create_advanced_group(group_name, group_description, params, s_class_name_01, s_group_name_01, s_node_name_01)
        modify_advanced_group(group_name_new, group_description_new, params_new, s_class_name_02, s_group_name_02, s_node_name_02)
      end

      after :all do
        remove_group(group_name_new)
      end

      it 'should have a group' do
        should_have_group(group_name_new)
      end

      it 'should not have a group' do
        should_not_have_group(group_name)
      end

      it 'should have the set description' do
        select_group(group_name_new)
        session.should have_css('div#main div[class*="description"] p', :text => group_description_new)
      end

      it 'should have the added variables' do
        select_group(group_name_new)
        show_should_have_variables(params_new)
      end

      it 'should have the new class' do
        select_group(group_name_new)
        classes_table = get_inspector_table('Classes')
        classes_table.should have_css('a', :text => s_class_name_02)
      end

      it 'should not have the old class' do
        select_group(group_name_new)
        classes_table = get_inspector_table('Classes')
        classes_table.should have_no_css('a', :text => s_class_name_01)
      end

      it 'should have the new group' do
        select_group(group_name_new)
        classes_table = get_inspector_table('Groups')
        classes_table.should have_css('a', :text => s_group_name_02)
      end

      it 'should not have the old group' do
        select_group(group_name_new)
        classes_table = get_inspector_table('Groups')
        classes_table.should have_no_css('a', :text => s_group_name_01)
      end

      it 'should have the new node' do
        select_group(group_name_new)
        session.should have_css(%Q{div#main table.main a[href*="#{s_node_name_02}"]}, :text => s_node_name_02)
      end

      it 'should not have the old node' do
        select_group(group_name_new)
        session.should have_no_css(%Q{div#main table.main a[href*="#{s_node_name_01}"]}, :text => s_node_name_01)
      end
    end
  end

end

def create_advanced_group(group_name, group_description, params, ref_class_name, ref_group_name, ref_node_name)
  session.find('#sidebar').click_link('Add group')
  form_node = session.find('#param_form', :visible => true)

  form_node.fill_in('node_group_name', :with => "#{group_name}")
  form_node.fill_in('node_group_description', :with => "#{group_description}")

  # add variables
  add_variables(params)

  # set class
  set_field_with_suggestion('class', ref_class_name)

  # set group
  set_field_with_suggestion('group', ref_group_name)

  # set node
  set_field_with_suggestion('node', ref_node_name)

  form_node.click_button('Create')
  wait_for_modification
end

def modify_advanced_group(group_name, group_description, params, ref_class_name, ref_group_name, ref_node_name)
  edit_button_css = '#main a.edit.button'
  session.find(edit_button_css).click()
  form_node = session.find('#param_form', :visible => true)

  form_node.fill_in('node_group_name', :with => "#{group_name}")
  form_node.fill_in('node_group_description', :with => "#{group_description}")

  # modify variables
  remove_variables
  add_variables(params)

  # replace class
  remove_field_with_suggestion_values('class')
  set_field_with_suggestion('class', ref_class_name)

  # replace group
  remove_field_with_suggestion_values('group')
  set_field_with_suggestion('group', ref_group_name)

  # replace node
  remove_field_with_suggestion_values('node')
  set_field_with_suggestion('node', ref_node_name)

  form_node.click_button('Update')
  wait_for_modification
end
