PuppetDashboard::Application.routes do

  root :to => 'pages#home'

  resources :node_classes do
    collection do
      get :select
      get :search
      get :docs
    end
    member do
      get :select_parameters
    end
  end

  resources :node_class_memberships do
    collection do
      get :search
    end
  end

  resources :node_group_class_memberships do
    collection do
      get :search
    end
  end

  resources :node_groups do
    member do
      get :diff
    end
    collection do
      get :search
    end
  end

  constraints(:id => /[^\/]+/) do
    resources :nodes do
      member do
        put :hide
        put :unhide
        get :facts
        get :reports
      end
      collection do
        get :unreported
        get :failed
        get :pending
        get :unresponsive
        get :changed
        get :unchanged
        get :hidden
        get :search
      end
    end
  end

  resources :reports do
    collection do
      get :search
    end
  end

  resources :node_group_memberships
  resources :memberships, :controller => :node_group_memberships

  match 'files/:action/:file1/:file2' => 'files#:action'
  match 'files/:action/:file'         => 'files#:action'

  match '/header.:format' => 'pages#header'
  match 'release_notes'   => 'pages#release_notes', :via => :get

  match 'reports/upload'  => 'reports#upload', :via => :post
  get 'reports/:certname/:report_time' => 'reports#by_node_and_time', :format => false, :constraints => {
    :certname => /[A-Za-z0-9\.\-_]+?/,
    :report_time => /[0-9]{4}-[0-9]{2}-[0-9]{2}T[0-9]{2}:[0-9]{2}:[0-9]{2}\.[0-9]{3}Z/
  }

  match '/delayed_job_failures/read_all' => 'delayed_job_failures#read_all', :via => :post

  get 'radiator(.:format)' => 'radiator#index'

  get ':controller(/:action(/:id(.:format)))'
end
